@@ -96,10 +96,11 @@ class LabelSelectionOp(BaseOp):
     def __init__(self, labels, level=None):
         if isinstance(labels, list):
             labels = tuple(labels)
-        elif not isinstance(labels, tuple):
+        elif not isinstance(labels, (slice, tuple)):
+            # Convert "scalar" values to some iterable
             labels = (labels,)
         self.labels = labels
-        self.level=level
+        self.level = level
 
     def __call__(self, axis, df):
         labels = getattr(df, axis)
@@ -110,8 +111,29 @@ class LabelSelectionOp(BaseOp):
             cands = labels.get_level_values(self.level)
 
         indices = []
-        for lbl in self.labels:
-            indices.extend(idx[cands == lbl])
+        if isinstance(self.labels, tuple):
+            for lbl in self.labels:
+                indices.extend(idx[cands == lbl])
+        elif isinstance(self.labels, slice):
+            # NOTE: We need to make this more complex because we also need
+            # to treat situation with multiple repetitions of the same
+            # value, e.g., cases of multi-index levels.
+            in_slice = self.labels.start is None
+            reached_slice_stop = False
+            for i, lbl in enumerate(cands):
+                if not in_slice and lbl == self.labels.start:
+                    in_slice = True
+                if reached_slice_stop and lbl != self.labels.stop:
+                    # We stepped over the end of the slice.
+                    break
+                if in_slice:
+                    indices.append(i)
+                    if self.labels.stop is not None and lbl == self.labels.stop:
+                        reached_slice_stop = True
+        else:
+            # This should never be reached becaus of the argument processing
+            # in __init__.
+            raise ValueError(f"Unexpected type for self.labels: {type(self.labels)}: {self.labels!r}")
 
         return Selection(indices)
 
@@ -327,6 +349,69 @@ class DtypeComposer:
 
 
 class SelectionComposerBase(LabelComposer):
+    """Compose callable to select or sort axis labels (index and columns).
+
+    .. note::
+        Use :class:`ColumnSelectionComposer` (``C``) if you want to select
+        columns.
+
+    This acts as global entrypoint.
+
+    Use the global instance like::
+
+        # Move rows x, z to the top
+        from pandas_paddles import I
+        df.loc[I["x", "z"] | ...]
+
+    Other use-cases:
+
+    - Select slices of rows::
+
+        df.loc[I["B":"E"] | I["P":"S"]]
+
+    - Select all rows with index starting with ``"PRE"``::
+
+        df.loc[I.startswith("PRE")]
+        # or just move them to the top and keep the remaining columns in
+        # the data frame
+        df.loc[I.startswith("PRE") | ...]
+
+    - Access the level of a multi-index with::
+
+        I.levels[0]
+        I.levels["level-name"]
+
+    Selections can be combined with ``&`` (intersection) and ``|`` or ``+``
+    (union). In intersections, the right-most order takes precedence, while
+    it's the left-most for unions, e.g. the following will select all
+    rows with first-level label "b" starting with the rows with
+    second-level labels "Y" and "Z" followed by all other second-level
+    labels with first-level "b"::
+
+        I.levels[0]["b"] & (I.levels[1]["Y"] | ...)
+
+    Inversion (negation) of selections is possible with ``~``, e.g. to select all but first-level label "b"::
+
+        ~I.levels[0]["b"]
+
+    This can also be applied to composed selections::
+
+        ~(I.levels[0]["b"] | I.levels[1]["X", "Y"])
+    """
+    def __init__(self, axis, op=None):
+        super().__init__(axis, op=op)
+        self.levels = LeveledComposer(self.axis)
+
+    # Warn about experimental status of this feature.
+    # TODO: Remove once API is stable
+    def __getattribute__(self, name):
+        attr = super().__getattribute__(name)
+        if name != "__init__":
+            warn("Column/index selection is an experimental feature! The API might change in minor version updates.", stacklevel=2)
+        return attr
+
+
+class ColumnSelectionComposer(SelectionComposerBase):
     """Compose callable to select or sort columns.
 
     This acts as global entrypoint.
@@ -339,6 +424,11 @@ class SelectionComposerBase(LabelComposer):
 
     Other use-cases:
 
+    - Select slices of columns, e.g., when handling Excel-like named columns
+      (A, B, ...)::
+
+        df.loc[:, C["B":"E"] | C["P":"S"]]
+
     - Select by dtype::
 
         df.loc[:, C.dtype == str]
@@ -357,6 +447,11 @@ class SelectionComposerBase(LabelComposer):
         # the data frame
         df.loc[:, C.startswith("PRE") | ...]
 
+    - Access the level of a multi-index with::
+
+        C.levels[0]
+        C.levels["level-name"]
+
     Selections can be combined with ``&`` (intersection) and ``|`` or ``+``
     (union). In intersections, the right-most order takes precedence, while
     it's the left-most for unions, e.g. the following will select all
@@ -374,20 +469,6 @@ class SelectionComposerBase(LabelComposer):
 
         ~(C.levels[0]["b"] | C.levels[1]["X", "Y"])
     """
-    def __init__(self, axis, op=None):
-        super().__init__(axis, op=op)
-        self.levels = LeveledComposer(self.axis)
-
-    # Warn about experimental status of this feature.
-    # TODO: Remove once API is stable
-    def __getattribute__(self, name):
-        attr = super().__getattribute__(name)
-        if name != "__init__":
-            warn("Column/index selection is an experimental feature! The API might change in minor version updates.", stacklevel=2)
-        return attr
-
-
-class ColumnSelectionComposer(SelectionComposerBase):
     def __init__(self, axis, op=None, sample_size=None):
         super().__init__(axis, op=op)
         self.dtype = DtypeComposer(self.axis)
